@@ -336,8 +336,10 @@ static void timer(ENTRY *entry)
 	case as_invalid:
 	    if (entry->vccs) inarp_request(entry);
 	    else if (!(entry->flags & ATF_ARPSRV))
-		    diag(COMPONENT,DIAG_ERROR,"as_invalid, no VCCs, but not "
+		    diag(COMPONENT,DIAG_INFO,"as_invalid, no VCCs, but not "
 		      "ARP server entry");
+			/* this is a valid condition if we're the ATMARP server
+			   and the remote disconnected */
 		    else if (!want_arp_srv(entry->itf)) STOP_TIMER(entry);
 	    break;
 	case as_valid:
