@@ -323,6 +323,7 @@ static void accept_new(void)
 		    if (set_ip(vcc->fd,entry->ip) < 0)
 			diag(COMPONENT,DIAG_ERROR,"set_ip: %s",
 			  strerror(errno));
+		set_sndbuf(vcc);
 		return;
 	    }
 	}
@@ -339,27 +340,39 @@ static void accept_new(void)
 }
 
 
-int connect_vcc(struct sockaddr *remote,const struct atm_qos *qos,int timeout)
+int connect_vcc(struct sockaddr *remote,const struct atm_qos *qos,int sndbuf,
+  int timeout)
 {
-    int fd,flags;
+    int fd,error,flags;
 
     if (remote->sa_family == AF_ATMSVC && incoming < 0) return -EUNATCH;
     if ((fd = socket(remote->sa_family,SOCK_DGRAM,0)) < 0) {
+	error = -errno;
 	diag(COMPONENT,DIAG_ERROR,"socket: %s",strerror(errno));
-	return -errno;
+	return error;
     }
     if (setsockopt(fd,SOL_ATM,SO_ATMQOS,qos,sizeof(*qos)) < 0) {
+	error = -errno;
 	diag(COMPONENT,DIAG_ERROR,"setsockopt SO_ATMQOS: %s",strerror(errno));
-	return -errno;
+	return error;
     }
+    if (sndbuf)
+	if (setsockopt(fd,SOL_SOCKET,SO_SNDBUF,&sndbuf,sizeof(sndbuf)) < 0) {
+	    error = -errno;
+	    diag(COMPONENT,DIAG_ERROR,"setsockopt SO_SNDBUF: %s",
+	      strerror(errno));
+	    return error;
+	}
     if ((flags = fcntl(fd,F_GETFL)) < 0) {
+	error = -errno;
 	diag(COMPONENT,DIAG_ERROR,"fcntl F_GETFL: %s",strerror(errno));
-	return -errno;
+	return error;
     }
     flags |= O_NONBLOCK;
     if (fcntl(fd,F_SETFL,flags) < 0) {
+	error = -errno;
 	diag(COMPONENT,DIAG_ERROR,"fcntl F_GETFL: %s",strerror(errno));
-	return -errno;
+	return error;
     }
     if (remote->sa_family == AF_ATMSVC) { /* @@@ that's cheating */
 	struct atm_sap sap;
@@ -368,24 +381,27 @@ int connect_vcc(struct sockaddr *remote,const struct atm_qos *qos,int timeout)
 	sap.blli[0].l2_proto = ATM_L2_ISO8802;
 	sap.blli[0].l3_proto = ATM_L3_NONE;
 	if (setsockopt(fd,SOL_ATM,SO_ATMSAP,&sap,sizeof(sap)) < 0) {
+	    error = -errno;
 	    diag(COMPONENT,DIAG_ERROR,"setsockopt SO_ATMSAP: %s",
 	      strerror(errno));
-	    return -errno;
+	    return error;
 	}
     }
     /* PVC connect never blocks */
     if (connect(fd,remote,remote->sa_family == AF_ATMPVC ?
       sizeof(struct sockaddr_atmpvc) : sizeof(struct sockaddr_atmsvc)) < 0) {
 	if (errno != EINPROGRESS) {
+	    error = -errno;
 	    diag(COMPONENT,DIAG_ERROR,"[1]connect: %s",strerror(errno));
-	    return -errno;
+	    return error;
 	}
 	return fd;
     }
     if (ioctl(fd,ATMARP_MKIP,timeout) < 0) {
+	error = -errno;
         diag(COMPONENT,DIAG_ERROR,"ioctl ATMARP_MKIP: %s",strerror(errno));
         (void) do_close(fd);
-        return -errno;
+        return error;
     }
     return fd;
 }
@@ -393,19 +409,34 @@ int connect_vcc(struct sockaddr *remote,const struct atm_qos *qos,int timeout)
 
 int set_ip(int fd,int ip)
 {
+    int error;
+
     if (ioctl(fd,ATMARP_SETENTRY,ip) >= 0) return 0;
+    error = -errno;
     diag(COMPONENT,DIAG_ERROR,"ioctl ATMARP_SETENTRY: %s",strerror(errno));
     (void) do_close(fd);
-    return -errno;
+    return error;
 }
 
 
 int set_encap(int fd,int mode)
 {
+    int error;
+
     if (ioctl(fd,ATMARP_ENCAP,mode) >= 0) return 0;
+    error = -errno;
     diag(COMPONENT,DIAG_ERROR,"ioctl ATMARP_ENCAP: %s",strerror(errno));
     (void) do_close(fd);
-    return -errno;
+    return error;
+}
+
+
+void set_sndbuf(VCC *vcc)
+{
+    if (setsockopt(vcc->fd,SOL_SOCKET,SO_SNDBUF,&vcc->entry->sndbuf,
+      sizeof(int)) >= 0)
+	return;
+    diag(COMPONENT,DIAG_ERROR,"setsockopt SO_SNDBUF: %s",strerror(errno));
 }
 
 
