@@ -1,6 +1,6 @@
 /* znth.c - ZN122x timestamp adjustments history */
 
-/* Written 1996,1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1996-1998 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #include <stdlib.h>
@@ -8,7 +8,7 @@
 #include <sys/socket.h>
 #include <sys/ioctl.h>
 #include <sys/time.h>
-#include <linux/atm.h>
+#include <atm.h>
 #include <linux/atm_zatm.h>
 
 
