@@ -32,6 +32,7 @@
 #include <sys/time.h>
 #include <unistd.h>
 #include <signal.h>
+#include <ctype.h>
 #include <string.h>
 #include <getopt.h>
 #include <errno.h>
@@ -185,6 +186,7 @@ int main(int argc, char **argv)
         char atm2textbuff[100];
         char esibuff[20];
         int esi_set = 0;
+        int listen_addr_set = 0;
         int atm_set=0;
         int proxy_flag = 0;
         int lane_version = 0;              /* LANE2 */
@@ -199,6 +201,7 @@ int main(int argc, char **argv)
         memset(preferred_les, 0, ATM_ESA_LEN);
         memset(&manual_atm_addr, 0, sizeof(struct sockaddr_atmsvc));
         memset(&listen_addr, 0, sizeof(struct sockaddr_atmsvc));
+        listen_addr.sas_family = AF_ATMSVC;
 
         set_application("zeppelin"); /* for debug msgs */
 
@@ -266,20 +269,17 @@ int main(int argc, char **argv)
 			  selector >=0 && selector <= 0xff) {
 				listen_addr.sas_addr.prv[ATM_ESA_LEN - 1] =
 				  (char) selector;
-				listen_addr.sas_family = AF_ATMSVC; 
 				diag(COMPONENT, DIAG_INFO, "Selector byte set "
 				  "to %d", selector);
-			}
-			else
-                        if (text2atm(optarg, (struct sockaddr *)&listen_addr,
-                                     sizeof(struct sockaddr_atmsvc), T2A_NAME) < 0) {
-                                diag(COMPONENT, DIAG_ERROR, "Invalid ATM listen address\n");
-                                usage(argv[0]);
-                                exit(-1);
+			} else {
+                                if (text2atm(optarg, (struct sockaddr *)&listen_addr,
+                                             sizeof(struct sockaddr_atmsvc), T2A_NAME) < 0) {
+                                        diag(COMPONENT, DIAG_ERROR, "Invalid ATM listen address\n");
+                                        usage(argv[0]);
+                                        exit(-1);
+                                }
+                                listen_addr_set = 1;
                         }
-                        atm2text(atm2textbuff, sizeof(atm2textbuff),
-                                 (struct sockaddr *)&listen_addr, 0);
-                        diag(COMPONENT, DIAG_INFO, "Our ATM address: %s\n", atm2textbuff);
                         break;
                 case 'i':
                         if (sscanf(optarg, "%d", &itf) <= 0 || itf >= MAX_LEC_ITF) {
@@ -356,11 +356,19 @@ int main(int argc, char **argv)
         /* Reserve signals */
         signal(SIGHUP, sig_reset);
 
-        if (get_listenaddr(listen_addr.sas_addr.prv, phys_itf) < 0) {
-                diag(COMPONENT, DIAG_FATAL, "Could not figure out my ATM address\n");
-                exit(-1);
+        if (!listen_addr_set) {
+                char sel = listen_addr.sas_addr.prv[ATM_ESA_LEN - 1];
+                if (get_listenaddr(listen_addr.sas_addr.prv, phys_itf) < 0) {
+                        diag(COMPONENT, DIAG_FATAL, "Could not figure out my ATM address\n");
+                        exit(-1);
+                }
+                listen_addr.sas_addr.prv[ATM_ESA_LEN - 1] = sel;
         }
 
+        atm2text(atm2textbuff, sizeof(atm2textbuff),
+                 (struct sockaddr *)&listen_addr, A2T_NAME | A2T_PRETTY | A2T_LOCAL);
+        diag(COMPONENT, DIAG_INFO, "Our ATM address: %s\n", atm2textbuff);
+
         if (!esi_set) {
                 if(addr_getesi(mac_addr, phys_itf) < 0) {
                         diag(COMPONENT, DIAG_ERROR, "Can't get ESI from kernel!\n");
