@@ -1,6 +1,6 @@
 /* atmsigd.c - ATM signaling demon */
 
-/* Written 1995-1999 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1995-2000 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #include <stdlib.h>
@@ -11,7 +11,6 @@
 #include <signal.h>
 #include <limits.h>
 #include <sys/types.h>
-#include <linux/atmdev.h>
 
 #include "atm.h"
 #include "atmd.h"
@@ -174,8 +173,8 @@ static void dump_status(FILE *file,const char *banner)
     for (sig = entities; sig; sig = sig->next) {
 	fprintf(file,"--- Entity %d.%d.%d ---\n",S_PVC(sig));
 	for (walk = sockets; walk; walk = walk->next) {
-	    fprintf(file,"0x%lx: %s, CR 0x%06lX, PVC %d.%d.%d\n",
-	      (unsigned long) walk->id,
+	    fprintf(file,"%s: %s, CR 0x%06lX, PVC %d.%d.%d\n",
+	      kptr_print(&walk->id),
 	      state_name[walk->state],walk->call_ref,walk->pvc.sap_addr.itf,
 	      walk->pvc.sap_addr.vpi,walk->pvc.sap_addr.vci);
 	    dump_addr(file,"local ",&walk->local);
@@ -419,7 +418,7 @@ int main(int argc,char **argv)
 	    default:
 		usage(argv[0]);
 	}
-    if (_entity.mode == sm_unknown)
+    if (_entity.mode == sm_unknown) {
 	if (net) {
 	    if (allocate_ci) {
 		_entity.mode = sm_net;
@@ -434,6 +433,7 @@ int main(int argc,char **argv)
 	}
 	else if (allocate_ci) _entity.mode = sm_user;
 	    else usage(argv[0]);
+    }
     if (optind < argc) {
 	manual_override();
 	if (text2atm(argv[optind],(struct sockaddr *) &_entity.signaling_pvc,
