@@ -1,16 +1,15 @@
 /* sap.c - SAP manipulations */
  
-/* Written 1996-1999 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1996-2000 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
-#include <stdint.h> /* linux/atmdev and linux/atmsvc.h include linux/atm.h */
+#include <atm.h>
 #include <linux/atmdev.h>
 #include <linux/atmsvc.h>
 
-#include "atm.h"
 #include "atmd.h"
 #include "uni.h"
 #include "qlib.h"
